@@ -26,6 +26,7 @@
 #ifndef XNEE_XNEE_H
 #define XNEE_XNEE_H
 
+#include <limits.h>
 #include <stdio.h>
 #include <unistd.h>
 #include <string.h>
@@ -96,8 +97,20 @@ enum return_values
     XNEE_RANGE_FAILURE     ,
     XNEE_BAD_OFFSET        ,
     XNEE_WINDOW_POS_ADJ_ERROR     ,
+    XNEE_MISSING_ARG       ,
+    XNEE_OK_LEAVE          ,
     XNEE_LAST_ERROR
   } _return_values;
+
+
+enum bool_string_values
+  {
+    XNEE_BOOL_EXPLICIT_FALSE=0,
+    XNEE_BOOL_IMPLICIT_TRUE,
+    XNEE_BOOL_EXPLICIT_TRUE,
+    XNEE_BOOL_ERROR
+  } _bool_string_values;
+
   
 
 /** 
@@ -144,7 +157,37 @@ struct data_description
   char *data_descr;
 };
 
+enum
+  {
+    XNEE_ANY_OPTION,
+    XNEE_GENERAL_OPTION,
+    XNEE_RECORD_OPTION,
+    XNEE_REPLAY_OPTION,
+    XNEE_SYNC_OPTION,
+    XNEE_GRAB_OPTION,
+    XNEE_MISC_OPTION,
+    XNEE_INTERNAL_OPTION,
+    XNEE_OBSOLETE_OPTION
+  } xnee_option_type;
 
+typedef struct
+{
+  int   key;
+  char *option; 
+  char *short_option; 
+  char *args; 
+  char *description; 
+  int   type;
+  int   visible;
+} xnee_option_t;
+
+/*
+typedef struct
+{
+  xnee_option_t   **options;
+  int             nr_of_options;
+} xnee_options_t;
+*/
 
 typedef struct 
 {
@@ -426,8 +469,9 @@ typedef struct
   XRecordContext      rContext;
   int 	data_flags;
   int	major_return;
-  int  minor_return ;
-  int  nclients; 
+  int   minor_return ;
+  int   nclients; 
+  int   active;
 } xnee_recordext_setup;
 
 
@@ -480,6 +524,9 @@ typedef struct
   /*@null@*/ /*@dependent@*/FILE    *rt_file     ;    /*!< retype file descriptor */
   /*@null@*/ /*@dependent@*/FILE    *buffer_file ;    /*!< verbose buffer printout file descriptor */
 
+  FILE    *saved_out_file    ;    /*!< output file descriptor */
+  FILE    *saved_err_file    ;    /*!< error file descriptor */
+
   char   **app_args    ;
 
   Bool     verbose     ;    /*!< true if verbose mode */
@@ -583,6 +630,19 @@ int
 xnee_check_false(char *expr);
 
 
+
+/**
+ * Allocates a new xnee_data structure. 
+ * To free the memory, xnee_free_xnee_data can be used.
+ * @return xnee_data * NULL if alloc failed
+ */
+/*@null@   The implementation of this function is located in xnee_alloc.c*/
+
+xnee_data*
+xnee_new_xnee_data(void);
+
+
+
 #define DEBUG_XNEE_DATA                                        
 #ifdef DEBUG_XNEE_DATA                                        
 void                                                          
