@@ -290,6 +290,8 @@ xnee_unset_all_clients (xnee_data *xd);
 int
 xnee_get_all_clients (xnee_data *xd);
 
+int
+xnee_is_future_clients_str(xnee_data *xd);
 
 int
 xnee_is_all_clients (xnee_data *xd);
@@ -470,6 +472,8 @@ xnee_set_xnee_printout (xnee_data *xd);
 
 #define xnee_is_human_printout(xd) (xd->rec_callback == xnee_human_dispatch)
 #define xnee_is_xnee_printout(xd)  (xd->rec_callback == xnee_record_dispatch)
+#define xnee_is_autorepeat(xd) (xd->autorepeat_saved!=0)
+
 
 int
 xnee_set_replay_speed_str (xnee_data *xd, const char *speed_str);
@@ -480,9 +484,27 @@ xnee_set_replay_speed (xnee_data *xd, int speed);
 int
 xnee_get_replay_speed(xnee_data *xd);
 
+int 
+xnee_set_replay_offset_str (xnee_data *xd, char *str);
+
+int 
+xnee_set_replay_offset_x(xnee_data *xd, int offset);
+
+int 
+xnee_set_replay_offset_y(xnee_data *xd, int offset);
+
+int 
+xnee_get_replay_offset_x(xnee_data *xd);
+
+int 
+xnee_get_replay_offset_y(xnee_data *xd);
 
 
 
+
+int 
+xnee_set_events_max_str (xnee_data *xd, char *str);
+
 int 
 xnee_set_events_max (xnee_data *xd, int loops);
 
@@ -525,6 +547,9 @@ xnee_get_time_left (xnee_data *xd);
 int
 xnee_set_store_mouse_pos(xnee_data *xd);
 
+int
+xnee_unset_store_mouse_pos(xnee_data *xd);
+
 Bool
 xnee_is_store_mouse_pos(xnee_data *xd);
 
@@ -560,6 +585,9 @@ xnee_get_application_parameters(xnee_data *xd);
 int
 xnee_set_new_window_pos (xnee_data *xd);
 
+int
+xnee_get_new_window_pos_value (xnee_data *xd);
+
 int
 xnee_unset_new_window_pos (xnee_data *xd);
 
@@ -569,6 +597,184 @@ xnee_set_recall_window_pos (xnee_data *xd);
 int
 xnee_unset_recall_window_pos (xnee_data *xd);
 
+char *
+xnee_get_project_name(xnee_data *xd);
 
+char *
+xnee_get_project_descr(xnee_data *xd);
+
+char *
+xnee_get_creat_date(xnee_data *xd);
+
+char *
+xnee_get_creat_program(xnee_data *xd);
+
+char *
+xnee_get_creat_prog_date(xnee_data *xd);
+
+char *
+xnee_get_last_date(xnee_data *xd);
+
+char *
+xnee_get_last_program(xnee_data *xd);
+
+char *
+xnee_get_last_prog_vers(xnee_data *xd);
+
+char *
+xnee_get_author_name(xnee_data *xd);
+
+char *
+xnee_get_author_email(xnee_data *xd);
+
+char *
+xnee_get_char(xnee_data *xd);
+
+char *
+xnee_get_project_name_str(xnee_data *xd);
+
+char *
+xnee_get_project_descr_str(xnee_data *xd);
+
+char *
+xnee_get_creat_date_str(xnee_data *xd);
+
+char *
+xnee_get_creat_prog_vers(xnee_data *xd);
+
+char *
+xnee_get_last_date_str(xnee_data *xd);
+
+char *
+xnee_get_last_prog_str(xnee_data *xd);
+
+char *
+xnee_get_last_prog_date_str(xnee_data *xd);
+
+char *
+xnee_get_author_name_str(xnee_data *xd);
+
+char *
+xnee_get_author_email_str(xnee_data *xd);
+
+char *
+xnee_get_char_str(xnee_data *xd);
+
+int
+xnee_set_first_list_str(xnee_data *xd, char *str);
+
+int
+xnee_set_all_clients_str(xnee_data *xd, char *str);
+
+
+int
+xnee_set_future_clients_str(xnee_data *xd, char *str);
+
+int
+xnee_set_future_clients(xnee_data *xd);
+
+int
+xnee_unset_future_clients(xnee_data *xd);
+
+int 
+xnee_set_data_max_str (xnee_data *xd, char *str);
+
+int 
+xnee_set_time_max_str (xnee_data *xd, char *str);
+
+int 
+xnee_set_sync_mode_str (xnee_data *xd, char *str);
+
+int 
+xnee_unset_sync_mode_str (xnee_data *xd, char *str);
+
+int 
+xnee_set_sync_mode(xnee_data *xd);
+
+int 
+xnee_get_sync_mode(xnee_data *xd);
+
+
+int 
+xnee_set_unsync_mode(xnee_data *xd);
+
+int 
+xnee_get_unsync_mode(xnee_data *xd);
+
+int 
+xnee_unset_sync_mode(xnee_data *xd);
+
+int
+xnee_set_buf_verbose(xnee_data *xd);
+
+int
+xnee_unset_buf_verbose(xnee_data *xd);
+
+const char *
+xnee_get_xosd_font(xnee_data *xd);
+
+int
+xnee_set_xosd_font(xnee_data *xd, char *font_str);
+
+int
+xnee_set_max_threshold_str (xnee_data *xd, char *thresh_str);
+
+int
+xnee_set_min_threshold_str (xnee_data *xd, char *thresh_str);
+
+int
+xnee_set_tot_threshold_str (xnee_data *xd, char *thresh_str);
+
+int
+xnee_set_max_threshold (xnee_data *xd, int thresh);
+
+int
+xnee_set_min_threshold (xnee_data *xd, int thresh);
+
+int
+xnee_set_tot_threshold (xnee_data *xd, int thresh);
+
+
+int
+xnee_set_rec_resolution_y (xnee_data *xd, int res);
+
+int
+xnee_set_rec_resolution_x (xnee_data *xd, int res);
+
+int
+xnee_set_rep_resolution_y (xnee_data *xd, int res);
+
+int
+xnee_set_rep_resolution_x (xnee_data *xd, int res);
+
+
+
+int
+xnee_get_max_threshold (xnee_data *xd);
+
+int
+xnee_get_min_threshold (xnee_data *xd);
+
+int
+xnee_get_tot_threshold (xnee_data *xd);
+
+int
+xnee_set_rec_resolution (xnee_data *xd, char *res_str);
+ 
+int
+xnee_get_rec_resolution_x (xnee_data *xd);
+
+int
+xnee_get_rec_resolution_y (xnee_data *xd);
+
+int
+xnee_set_rep_resolution (xnee_data *xd, char *res_str);
+
+int
+xnee_get_rep_resolution_x (xnee_data *xd);
+
+int
+xnee_get_rep_resolution_y (xnee_data *xd);
+ 
 
 #endif /* XNEE_SETGET_H */ 
