@@ -18,8 +18,8 @@
  *                                                                   
  * You should have received a copy of the GNU General Public License 
  * along with this program; if not, write to the Free Software       
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston,            
- * MA  02111-1307, USA.                                              
+ * Foundation, Inc., 51 Franklin Street, Boston,            
+ * MA  02110-1301, USA.                                              
  ****/
 
 #include "libxnee/xnee.h"
@@ -52,7 +52,7 @@ xnee_verbosef (xnee_data *xd, /*@null@*/ char * msg,  ...)
      return;
   }
 
-  if (xd->verbose!=0) 
+  if ( (xd->verbose!=0) && (xd->err_file!=NULL) )
     {
       va_start(ap, msg);
       (void)xd->verbose_fp ( xd->err_file, msg, ap );
@@ -72,7 +72,7 @@ xnee_verbosef (xnee_data *xd, valist)
      return;
   }
 
-  if (xd->verbose) 
+  if ( (xd->verbose!=0) && (xd->err_file!=NULL) )
     {
       va_start(argp);
       fmt = va_arg(argp, char *);
