@@ -79,6 +79,10 @@ xnee_expression_handle_projinfo(xnee_data *xd, char *tmp);
 static int
 xnee_expression_handle_newwindow(xnee_data *xd, char *tmp);
 
+static int
+xnee_is_replayable(xnee_data *xd, char *tmp);
+
+
 /*************************************************************
  *    public api 
  *************************************************************/
@@ -161,6 +165,10 @@ xnee_expression_handle_project(xnee_data *xd, char *tmp)
       return XNEE_BLANK_LINE;
     }
   
+  /* Is it a replayable data */
+  do_continue = xnee_is_replayable(xd, tmp);
+  if (do_continue) { return (XNEE_REPLAY_DATA); }
+  
 
   /* Is it a meta string */
   do_continue = xnee_expression_handle_comment(xd, tmp);
@@ -182,7 +190,6 @@ xnee_expression_handle_project(xnee_data *xd, char *tmp)
   do_continue = xnee_expression_handle_projinfo(xd, tmp);
   if (do_continue==XNEE_PROJECT_INFORMATION_DATA) { return (do_continue); }
   
-
   return (XNEE_SYNTAX_ERROR);
 }
 
@@ -268,408 +275,53 @@ xnee_expression_handle_replay(xnee_data *xd,
   return ret;
 }
 
+
 static int
 xnee_expression_handle_settings(xnee_data *xd, char *tmp)
 {
   #define RANGE_BUF_SIZE 100
   int ret=XNEE_SETTINGS_DATA;  
+  char **ret_strptr;
   char *range_tmp = NULL;
   char *range = NULL;
   char range_buf[RANGE_BUF_SIZE];
+  char opt_buf[RANGE_BUF_SIZE];
+  char *opt;
   int len=0;
-  
-  xnee_verbose ((xd, "handling settings: %s\n", tmp));
-  len=strlen(tmp);
+  char *my_tmp;
+  int   option_key;
 
-  /* OK the string passed the first tests */
-  range_tmp=strstr (tmp, " ");
-
-  if (range_tmp!=NULL) 
+  if (tmp==NULL)
     {
-      strncpy(range_buf, range_tmp, RANGE_BUF_SIZE );
-      
-      len=strlen(range_buf);
-      
-      rem_begin_blanks (range_buf, len);
-      
-      len=strlen(range_buf);
-      do 
-	{
-	  range_buf[len-1]='\0';
-	} while ( 
-		 (range_buf[len-1]=='\n')
-		 || 
-		 (range_buf[len-1]=='\r')
-		 );
-	   
-      
-      range = &range_buf[0];
-      if (len==0)
-	{
-	  range = NULL;
-	}
-    }
-  
-  if (!strncmp(XNEE_DISPLAY,tmp,strlen(XNEE_DISPLAY)))
-    {
-      ret = xnee_set_display_name (xd, range) ;
-    }
-  else if (!strncmp(XNEE_FIRST_LAST,tmp,strlen(XNEE_FIRST_LAST)))
-    {
-      if (xnee_check_true(range))
-	{
-	  ret = xnee_set_first_last(xd);
-	}
-      else if (xnee_check_false(range))
-	{
-	  ret = xnee_unset_first_last(xd);
-	}
-      else
-	{
-	  xnee_verbose((xd, "First last mode is invalid ... bailing out\n"));
-	  xnee_set_err_string("Could not parse %s", tmp);
-	  return XNEE_SYNTAX_ERROR;
-	}
-    }
-  else if (!strncmp(XNEE_SYNC_MODE,tmp,strlen(XNEE_SYNC_MODE)))
-    {
-      if (xnee_check_true(range))
-	{
-	  xd->sync = True;
-	}
-      else if (xnee_check_false(range))
-	{
-	  xd->sync = False;
-	}
-      else
-	{
-	  xnee_verbose((xd, "Sync is invalid ... bailing out\n"));
-	  xnee_set_err_string("Could not parse %s", tmp);
-	  return XNEE_SYNTAX_ERROR;
-	}
-      ret = XNEE_OK;
-    }
-  else if (!strncmp(XNEE_HUMAN_PRINTOUT,tmp,strlen(XNEE_HUMAN_PRINTOUT)))
-    {
-      if (xnee_check_true(range))
-	xnee_set_human_printout (xd);
-      else if (xnee_check_false(range))
-	xnee_set_xnee_printout (xd);
-      else
-	{
-	  xnee_verbose((xd, "Printout mode is invalid ... bailing out\n"));
-	  xnee_set_err_string("Could not parse %s", tmp);
-	  return XNEE_SYNTAX_ERROR;
-	}
-      ret = XNEE_OK;
-    }
-  else if (!strncmp(XNEE_FORCE_REPLAY,tmp,strlen(XNEE_FORCE_REPLAY)))
-    {
-      if (xnee_check_true(range))
-	xd->force_replay = True;
-      else if (xnee_check_false(range))
-	xd->force_replay = False;
-      else
-	{
-	  xnee_verbose((xd, "Forced replay mode is invalid ... bailing out\n"));
-	  xnee_set_err_string("Could not parse %s", tmp);
-	  return XNEE_SYNTAX_ERROR;
-	}
-      ret = XNEE_OK;
-    }
-  else if (!strncmp(XNEE_ALL_CLIENTS,tmp,strlen(XNEE_ALL_CLIENTS)))
-    {
-       if ( range==NULL)
-          xd->all_clients = True;
-       else if (xnee_check_true(range))
-          xd->all_clients = True;
-       else if (xnee_check_false(range))
-          xd->all_clients = False;
-       else
-       {
-	  xnee_verbose((xd, "All clients mode is invalid ... bailing out\n"));
-	  xnee_set_err_string("Could not parse %s", tmp);
-	  return XNEE_SYNTAX_ERROR;
-       }
-      ret = XNEE_OK;
-    }
-  else if (!strncmp(XNEE_FUTURE_CLIENTS,tmp,strlen(XNEE_FUTURE_CLIENTS)))
-    {
-       if ( range==NULL)
-          xd->all_clients = False;
-       else if (xnee_check_true(range))
-          xd->all_clients = False;
-       else if (xnee_check_false(range))
-          xd->all_clients = True;
-       else
-       {
-	  xnee_verbose((xd, "Future clients mode is invalid ... bailing out\n"));
-	  xnee_set_err_string("Could not parse %s", tmp);
-	  return XNEE_SYNTAX_ERROR;
-       }
-      ret = XNEE_OK;
-    }
-  else if (!strncmp(XNEE_DIMENSION,tmp,strlen(XNEE_DIMENSION)))
-    {
-      ret = xnee_set_rec_resolution (xd, range); 
-      if ( ret != XNEE_OK)
-	{
-	  ret = XNEE_BAD_RESOLUTION;
-	}
-    }
-  else if (!strncmp(XNEE_VERBOSE,tmp,strlen(XNEE_VERBOSE)))  
-    {
-      if (xnee_check_true(range))
-	ret = xnee_set_verbose(xd);
-      else if (xnee_check_false(range))
-	ret = xnee_unset_verbose(xd);
-      else
-	{
-	  xnee_verbose((xd, "Verbose mode is invalid ... bailing out\n"));
-	  xnee_set_err_string("Could not parse %s", tmp);
-	  return XNEE_SYNTAX_ERROR;
-	}
-    }
-  else if (!strncmp(XNEE_BUFFER_VERBOSE,tmp,strlen(XNEE_BUFFER_VERBOSE)))  
-    {
-      if (xnee_check_true(range))
-	ret = xnee_set_buf_verbose(xd);
-      else if (xnee_check_false(range))
-	ret = xnee_unset_buf_verbose(xd);
-      else
-	{
-	  xnee_verbose((xd, "Buffer Verbose mode is invalid ... bailing out\n"));
-	  xnee_set_err_string("Could not parse %s", tmp);
-	  return XNEE_SYNTAX_ERROR;
-	}
-    }
-  else if (!strncmp(XNEE_DELAY_TIME,tmp,strlen(XNEE_DELAY_TIME))) 
-    {
-      ret = xnee_set_interval(xd, atoi(range));
-    }
-  else if (!strncmp(XNEE_ADJUST_RESOLUTION,tmp,strlen(XNEE_ADJUST_RESOLUTION))) 
-    {
-      if (xnee_check_true(range))
-	ret = xnee_set_resolution_used (xd);
-      else if (xnee_check_false(range))
-	ret = xnee_unset_resolution_used (xd);
-      else
-	{
-	  xnee_verbose((xd, "Resolution mode is invalid ... bailing out\n"));
-	  xnee_set_err_string("Could not parse %s", tmp);
-	  return XNEE_SYNTAX_ERROR;
-	}
-    }
-  else if (!strncmp(XNEE_REPLAY_RESOLUTION,tmp,strlen(XNEE_REPLAY_RESOLUTION)))
-    {
-      ret = xnee_set_rep_resolution (xd, range);
-    }
-  else if (!strncmp(XNEE_RECORDED_RESOLUTION,tmp,strlen(XNEE_RECORDED_RESOLUTION)))
-    {
-      ret = xnee_set_rec_resolution (xd, range);
-    }
-  else if (!strncmp(XNEE_NEW_WINDOW,tmp,strlen(XNEE_NEW_WINDOW)))
-    {
-      xnee_set_new_window_pos_value ( xd, atoi(range));
-    }
-  else if (!strncmp(XNEE_LOOPS,tmp,strlen(XNEE_LOOPS))) 
-    {
-      fprintf (stderr, "Obsolete option: '%s'\n", tmp);
-      ret = xnee_set_events_max(xd, atoi(range));
-    }
-  else if (!strncmp(XNEE_DATA_MAX,tmp,strlen(XNEE_DATA_MAX))) 
-    {
-      ret = xnee_set_data_max(xd, atoi(range));
-    }
-  else if (!strncmp(XNEE_EVENT_MAX,tmp,strlen(XNEE_EVENT_MAX))) 
-    {
-      ret = xnee_set_events_max(xd, atoi(range));
-    }
-  else if (!strncmp(XNEE_TIME_MAX,tmp,strlen(XNEE_TIME_MAX))) 
-    {
-      ret = xnee_set_time_max(xd, atoi(range));
-    }
-  else if (!strncmp(XNEE_SPEED_PERCENT,tmp,strlen(XNEE_SPEED_PERCENT))) 
-    {
-      ret = xnee_set_replay_speed_str (xd, range);
-    }
-  else if (!strncmp(XNEE_STOP_KEY,tmp,strlen(XNEE_STOP_KEY)))
-    {
-      /* If there is a '0', we should not read it */
-      if (!xnee_check_false(range))
-	{
-	  ret = xnee_set_key (xd, XNEE_GRAB_STOP, range);
-	}
-      else
-	{
-	  ret = XNEE_OK;
-	}
-    }
-  else if (!strncmp(XNEE_PAUSE_KEY,tmp,strlen(XNEE_PAUSE_KEY)))
-    {
-      /* If there is a '0', we should not read it */
-      if (!xnee_check_false(range))
-	ret = xnee_set_key (xd, XNEE_GRAB_PAUSE, range);
-      else
-	{
-	  ret = XNEE_OK;
-	}
-    }
-  else if (!strncmp(XNEE_RESUME_KEY,tmp,strlen(XNEE_RESUME_KEY)))
-    {
-      if (!xnee_check_false(range))
-	  ret = xnee_set_key (xd, XNEE_GRAB_RESUME, range);
-      else
-	{
-	  ret = XNEE_OK;
-	}
-    }
-  else if (!strncmp(XNEE_INSERT_KEY,tmp,strlen(XNEE_INSERT_KEY)))
-    {
-      if (!xnee_check_false(range))
-	  ret = xnee_set_key (xd, XNEE_GRAB_INSERT, range);
-      else
-	{
-	  ret = XNEE_OK;
-	}
-    }
-  else if (!strncmp(XNEE_EXEC_KEY,tmp,strlen(XNEE_EXEC_KEY)))
-    {
-      if (!xnee_check_false(range))
-	ret = xnee_set_key (xd, XNEE_GRAB_EXEC, range);
-      else
-	{
-	  ret = XNEE_OK;
-	}
-    }
-  else if (!strncmp(XNEE_EXEC_PROGRAM,tmp,strlen(XNEE_EXEC_PROGRAM)))
-    {
-      if ( (strncmp(XNEE_EXEC_NO_PROG, range, strlen(XNEE_EXEC_NO_PROG))==0))
-	{
-	  xnee_verbose((xd, "found no program to exec\n"));
-	}
-      else
-	{
-	  xnee_verbose((xd, "found program to exec: %s\n", range));
- 	  ret = xnee_set_exec_prog (xd, range); 
-	}
+      xnee_verbose ((xd, "handling settings: NULL returning\n"));
+      return XNEE_WRONG_PARAMS;
     }
 
-  /* These are specific to xnee 
-   *
-   *
-   *  Don't use
-   *
-   */
-   else if (!strncmp(XNEE_STORE_MOUSE_POS,tmp,strlen(XNEE_STORE_MOUSE_POS)))  
-     {	  
-       xnee_set_store_mouse_pos(xd);
-     } 
-/*   else if (!strncmp(XNEE_KEYBOARD,tmp,strlen(XNEE_KEYBOARD)))  */
-/*     {	  */
-/*       ret = xnee_parse_range (xd, XNEE_DEVICE_EVENT,  */
-/* 			"KeyPress-KeyRelease"); */
-      
-/*     } */
-/*   else if (!strncmp(XNEE_MOUSE,tmp,strlen(XNEE_MOUSE))) */
-/*     { */
-/*       ret = xnee_parse_range (xd, XNEE_DEVICE_EVENT,  */
-/* 			"ButtonPress-MotionNotify"); */
-/*     } */
-  else if (!strncmp(XNEE_PLUGIN,tmp,strlen(XNEE_PLUGIN))) 
-    {
-      /* If there is a '0', we should not read it */
-      if (!xnee_check_false(range))
-	ret = xnee_use_plugin (xd, range);
-      else
-	ret = XNEE_OK;
+  xnee_verbose ((xd, "handling settings: '%s'\n", tmp));
+
+
+  if ( xnee_is_replayable(xd, tmp) == XNEE_REPLAY_DATA) 
+    { 
+      return (XNEE_REPLAY_DATA); 
     }
-  else if (!strncmp(XNEE_OUT_FILE,tmp,strlen(XNEE_OUT_FILE))) 
+
+  my_tmp = tmp;
+
+  ret_strptr = xnee_str2strptr(my_tmp, 1);
+
+  if (xnee_is_verbose(xd))
     {
-      ret = xnee_set_out_name (xd, range);
+      xnee_print_strptr(ret_strptr);
     }
-  else if (!strncmp(XNEE_ERR_FILE,tmp,strlen(XNEE_ERR_FILE))) 
-    {
-      ret = xnee_set_err_name (xd, range);
-    }
-  else if (!strncmp(XNEE_FEEDBACK_XOSD,tmp,strlen(XNEE_FEEDBACK_XOSD))) 
-    {
-      ret = xnee_set_xosd_feedback(xd);
-    }
-  else if (!strncmp(XNEE_FEEDBACK_STDERR,tmp,strlen(XNEE_FEEDBACK_STDERR))) 
-    {
-      ret = xnee_set_stderr_feedback(xd);
-    }
-  else if (!strncmp(XNEE_FEEDBACK_NONE,tmp,strlen(XNEE_FEEDBACK_NONE))) 
-    {
-      ret = xnee_set_no_feedback(xd);
-    }
-  else if (!strncmp(XNEE_DISTRIBUTE,tmp,strlen(XNEE_DISTRIBUTE)))
-    {
-       if ( (range==NULL ) || (strlen(range)==0) )
-       {
-          ret = XNEE_OK ;
-       }
-       else
-       {
-          ret = xnee_add_display_list ( xd, range);
-       }
-    }
-  else if (!strncmp(XNEE_DEVICE_EVENT_STR,tmp,strlen(XNEE_DEVICE_EVENT_STR)))
-    {
-      ret = xnee_parse_range ( xd, XNEE_DEVICE_EVENT, range);
-    }
-  else if (!strncmp(XNEE_DELIVERED_EVENT_STR,
-		    tmp,strlen(XNEE_DELIVERED_EVENT_STR)))
-    {
-      ret = xnee_parse_range ( xd, XNEE_DELIVERED_EVENT, range);
-    }
-  else if (!strncmp(XNEE_ERROR_STR,tmp,strlen(XNEE_ERROR_STR))) 
-    {
-      ret = xnee_parse_range ( xd, XNEE_ERROR, range);
-    }
-  else if (!strncmp(XNEE_REQUEST_STR,tmp,strlen(XNEE_REQUEST_STR)))
-    {
-      ret = xnee_parse_range ( xd, XNEE_REQUEST, range);
-    }
-  else if (!strncmp(XNEE_REPLY_STR,tmp,strlen(XNEE_REPLY_STR)))  
-    {
-      ret = xnee_parse_range ( xd, XNEE_REPLY, range);
-    }
-  else if (!strncmp(XNEE_EXT_REQ_MAJ_STR,tmp,strlen(XNEE_EXT_REQ_MAJ_STR)))
-    {
-      ret = xnee_parse_range ( xd, XNEE_EXT_REQUEST_MAJOR, range);
-    }
-  else if (!strncmp(XNEE_EXT_REQ_MIN_STR,tmp,strlen(XNEE_EXT_REQ_MIN_STR)))
-    {
-      ret = xnee_parse_range ( xd, XNEE_EXT_REQUEST_MINOR, range);
-    }
-  else if (!strncmp(XNEE_EXT_REP_MAJ_STR,tmp,strlen(XNEE_EXT_REP_MAJ_STR))) 
-    {
-      ret = xnee_parse_range ( xd, XNEE_EXT_REPLY_MAJOR, range);
-    }
-  else if (!strncmp(XNEE_EXT_REP_MIN_STR,tmp,strlen(XNEE_EXT_REP_MIN_STR))) 
-    {
-      ret = xnee_parse_range ( xd, XNEE_EXT_REPLY_MINOR, range);
-    }
-  else if (!strncmp(XNEE_MAX_THRESHOLD,tmp,strlen(XNEE_MAX_THRESHOLD))) 
-    {
-      ret = xnee_set_max_threshold (xd,atoi(range));
-    }
-  else if (!strncmp(XNEE_MIN_THRESHOLD,tmp,strlen(XNEE_MIN_THRESHOLD))) 
-    {
-      ret = xnee_set_min_threshold (xd,atoi(range));
-    }
-  else if (!strncmp(XNEE_TOT_THRESHOLD,tmp,strlen(XNEE_TOT_THRESHOLD))) 
-    {
-      ret = xnee_set_tot_threshold (xd,atoi(range));
-    }
-  else 
-    {
-      ret=-1;
-    }      
+
+  option_key = xnee_option2key(xd, ret_strptr);
+
+  xnee_free_strptr(ret_strptr);
+
   if (ret==XNEE_OK)
-    ret = XNEE_SETTINGS_DATA;
+    {
+      ret = XNEE_SETTINGS_DATA;
+    }
 
   return ret;
 }
@@ -703,6 +355,8 @@ xnee_expression_handle_action(xnee_data *xd, char *tmp)
   if (strncmp(XNEE_EXEC_MARK,tmp,strlen(XNEE_EXEC_MARK))==0)
   {
 
+    xnee_verbose ((xd, "** handling action: %s==%s\n", tmp, XNEE_EXEC_MARK));
+
 
     exec_prog = xnee_get_exec_prog(xd);
     if (exec_prog != NULL)
@@ -717,13 +371,7 @@ xnee_expression_handle_action(xnee_data *xd, char *tmp)
 	system (exec_prog);
 	return XNEE_ACTION_DATA;
       }
-    system("xterm -fg yellow -bg blue");
   }
-  else
-    {
-      xnee_verbose ((xd, "handling exec %d\n", xnee_get_exec_prog(xd)));
-      getchar();
-    }
   return -1;
 }
 
@@ -1136,3 +784,17 @@ xnee_expression_handle_prim(xnee_data *xd, char *str, xnee_intercept_data * xind
 }
 
 
+static int
+xnee_is_replayable(xnee_data *xd, char *tmp)
+{
+  char first_c ; 
+
+  first_c = tmp[0];
+
+
+  if ( ( first_c >= '0' ) && ( first_c<='3' ) )
+    {
+      return 1;
+    }
+  return 0;
+}
