@@ -33,19 +33,25 @@
 int  
 xnee_free_file (xnee_data *xd, /*@null@*/ char *file_name, /*@null@*/ FILE* file)
 {
+  xnee_verbose((xd, "Closing file=%s fd=%d\n", 
+		file_name, 
+		(int)file));
+  
+
    /*  @owned@  */ /* char *tmp = file_name ; */
    if ( file_name != NULL) 
    {
       /* Tell splint we REALLY want to cast FILE* to an int 
          .... it won't believe us else */
       /*@access FILE@*/
-       xnee_verbose((xd, "Closing file=%s fd=%d\n", 
-                     file_name, 
-                     (int)file));
-      
        XNEE_FREE_IF_NOT_NULL (file_name); 
-       XNEE_FCLOSE_IF_NOT_NULL ( file ) ;
     }
+
+   if (file!=NULL)
+     {
+       XNEE_FCLOSE_IF_NOT_NULL ( file ) ;
+     }
+
   return XNEE_OK;
 }
 
@@ -68,7 +74,10 @@ xnee_open_files(xnee_data *xd)
 	{
 	  xnee_verbose((xd, "---  xnee_open_files: opening err: %s\n", 
 			xd->err_name));
-	  XNEE_FCLOSE_IF_NOT_NULL(xd->err_file); 
+	      if ( xd->err_file != xd->saved_err_file )
+		{
+		  XNEE_FCLOSE_IF_NOT_NULL(xd->err_file); 
+		}
 	  xd->err_file = fopen (xd->err_name,"w");
 	  if (xd->err_file==NULL)
 	    {
@@ -90,7 +99,10 @@ xnee_open_files(xnee_data *xd)
 	    {
 	      xnee_verbose((xd, "---  xnee_open_files: opening out: %s\n", 
 			    xd->out_name));
-	      XNEE_FCLOSE_IF_NOT_NULL(xd->out_file); 
+	      if ( xd->out_file != xd->saved_out_file )
+		{
+		  XNEE_FCLOSE_IF_NOT_NULL(xd->out_file); 
+		}
 	      xd->out_file = fopen (xd->out_name,"w");
 	      if (xd->out_file==NULL)
 		return XNEE_FILE_NOT_FOUND;
