@@ -302,8 +302,9 @@ xnee_record_handle_event ( xnee_data *xd, /*@null@*/ XRecordInterceptData *xreci
                  
                  break;
 	    case CreateNotify:
-	      fprintf (out,"0,%u,0,0,0,0,0,%lu\n",
+	      fprintf (out,"0,%u,%lu,0,0,0,0,%lu\n",
 		       event_type,
+		       xrec_data->event.u.createNotify.window,
 		       xrecintd->server_time
 		       );
 	      break;
@@ -719,7 +720,6 @@ int
 xnee_has_record_extension(xnee_data *xd)
 {
   int ok=XNEE_OK;
-  (void)XSynchronize(xd->control,True);
 
   if  ( (xd == NULL)
         ||
@@ -807,29 +807,29 @@ xnee_setup_recording(xnee_data *xd)
    */
   /*
     XRecordUnregisterClients( xd->control, 
-			    xd->record_setup->rContext,
-			    xd->record_setup->xids,2);
-  
-
-  if(!XRecordGetContext(xd->control, xd->record_setup->rContext, (XRecordState **) xd->record_setup->rState))
-  {
+    xd->record_setup->rContext,
+    xd->record_setup->xids,2);
+    
+    
+    if(!XRecordGetContext(xd->control, xd->record_setup->rContext, (XRecordState **) xd->record_setup->rState))
+    {
     xnee_print_error ("\n Couldn't get the context information for Display %d\n", (int) xd->control) ;
     exit(1);
-  }
+    }
   */
-/*
-  XRecordFreeState(xd->record_setup->rState); 
-  xd->record_setup->rState=NULL; 
-*/
-
-  xnee_verbose((xd, "\t  GetContext      0x%lx (%d clients intercepted))\n", 
-		xd->record_setup->rContext, 
-		(int) ( (xd->record_setup->rState) - (xd->record_setup->nclients) )));   
+  /*
+    XRecordFreeState(xd->record_setup->rState); 
+    xd->record_setup->rState=NULL; 
+  */
+  
+/*   xnee_verbose((xd, "\t  GetContext      0x%lx (%d clients intercepted))\n",  */
+/* 		xd->record_setup->rContext,  */
+/* 		(int) ( (xd->record_setup->rState) - (xd->record_setup->nclients) )));    */
   
   /* Enable context for async interception 
-  XSynchronize(xd->data, True);  
+     XSynchronize(xd->data, True);  
   */
-
+  
   xnee_verbose((xd, "<---xnee_setup_recording\n"));
   XNEE_DEBUG ( (stderr ," <-- xnee_setup_recording()  \n"  ));
   return (0);
