@@ -183,139 +183,6 @@ xnee_replay_synchronize (xnee_data* xd)
 }
 
 
-
-
-
-
-/**************************************************************
- *                                                            *
- * xnee_handle_meta_data_sub1                                 *
- *                                                            *
- *                                                            *
- **************************************************************/
-static void
-xnee_handle_meta_data_sub1(int *dest, char *src_str, int comp_str_size)
-{
-  int val;
-  
-
-  if ( sscanf ( src_str + comp_str_size + 1 , "%d", &val)  == 0 ) 
-    {
-       (void) xnee_print_error ("Could not read value for argument (for \"%s\" from file)\n", src_str);
-    }
-  else
-    {
-      *dest = val;
-    }
-}
-
-
-
-
-
-/**************************************************************
- *                                                            *
- * xnee_handle_meta_data                                      *
- *                                                            *
- *                                                            *
- **************************************************************/
-int
-xnee_handle_meta_data(xnee_data* xd, char * str)
-{
-  char *range;
-  int   ret;
-
-  xnee_verbose((xd, "xnee_handle_meta_data     (xd, \"%s\");\n", str));
-
-  ret = xnee_rem_comment_start (xd, str);
-  XNEE_RETURN_IF_ERR(ret);
-
-  xnee_verbose((xd, "xnee_handle_meta_data (2) (xd, \"%s\");\n", str));
-
-  ret = rem_all_blanks (str, strlen(str));
-  XNEE_RETURN_IF_ERR(ret);
-
-  xnee_verbose((xd, "xnee_handle_meta_data (3) (xd, \"%s\");\n", str));
-
-  if (strncmp (str, XNEE_LOOPS_LEFT, strlen (XNEE_LOOPS_LEFT)) == 0  )
-    {
-       xnee_handle_meta_data_sub1 (&xd->xnee_info.events_max, str,  (int)strlen(XNEE_LOOPS_LEFT) );
-    }
-  else if (strncmp (str, XNEE_EVENT_MAX, strlen (XNEE_EVENT_MAX)) == 0  )
-    {
-       xnee_handle_meta_data_sub1 (&xd->xnee_info.events_max, str,  (int)strlen(XNEE_EVENT_MAX) );
-    }
-  else if (strncmp (str, XNEE_DATA_MAX, strlen (XNEE_DATA_MAX)) == 0  )
-    {
-       xnee_handle_meta_data_sub1 (&xd->xnee_info.data_max, str,  (int)strlen(XNEE_DATA_MAX) );
-    }
-  else if (strncmp (str, XNEE_TIME_MAX, strlen (XNEE_TIME_MAX)) == 0  )
-    {
-      xnee_handle_meta_data_sub1 (&xd->xnee_info.time_max, str,  (int)strlen(XNEE_TIME_MAX) );
-    }
-  else if ( 
-	   (strncmp (str, XNEE_REQUEST_STR, strlen (XNEE_REQUEST_STR)) == 0  )
-	   || 
-	   (strncmp (str, XNEE_DELIVERED_EVENT_STR, strlen (XNEE_DELIVERED_EVENT_STR)) == 0  )
-	   || 
-	   (strncmp (str, XNEE_ERROR_STR, strlen (XNEE_ERROR_STR)) == 0  )
-	   || 
-	   (strncmp (str, XNEE_REPLY_STR, strlen (XNEE_REPLY_STR)) == 0  )
-	   || 
-	   (strncmp (str, XNEE_EXT_REQ_MAJ_STR, strlen (XNEE_EXT_REQ_MAJ_STR)) == 0  )
-	   || 
-	   (strncmp (str, XNEE_EXT_REQ_MIN_STR, strlen (XNEE_EXT_REQ_MIN_STR)) == 0  )
-	   || 
-	   (strncmp (str, XNEE_EXT_REP_MAJ_STR, strlen (XNEE_EXT_REP_MAJ_STR)) == 0  )
-	   || 
-	   (strncmp (str, XNEE_EXT_REP_MIN_STR, strlen (XNEE_EXT_REP_MIN_STR)) == 0  )
-	   || 
-	   (strncmp (str, XNEE_STOP_KEY, strlen (XNEE_STOP_KEY)) == 0  )
-	   )
-    {
-      ret = xnee_add_resource_syntax(xd, str);
-      XNEE_RETURN_IF_ERR(ret);
-    }
-  else if (strncmp (str, XNEE_DEVICE_EVENT_STR, strlen (XNEE_DEVICE_EVENT_STR)) == 0 )
-    {
-      xnee_verbose((xd, " Skipping :\"%s\"\n", str));
-    }
-  else if ( strncmp (str, XNEE_META_END, strlen (XNEE_META_END)) == 0  )
-    {
-      /* once the meta end line is read - temp stop processing file until XRecord Async callback set up*/
-      return XNEE_FALSE;
-    }
-  else if ( strncmp(XNEE_DIMENSION,str,strlen(XNEE_DIMENSION)) != 0 )
-    {
-      range=strstr (str, ":");
-      range += 1 ;
-      if ( xnee_set_rec_resolution (xd, range) != 0)
-	{
-	  xnee_verbose ((xd, "failed to set recorded resolution\n"));
-	  xnee_close_down(xd);
-	  exit(XNEE_BAD_RESOLUTION );
-	}
-      xnee_verbose ((xd, "recored resolution= %dx%d\n", 
-		     xnee_get_rec_resolution_x(xd),
-		     xnee_get_rec_resolution_y(xd)));
-    }
-  else 
-    {
-      xnee_verbose((xd, " Skipping :\"%s\"\n", str));
-      ; /* TODO .... */
-      return -1;
-    }
-
-  /*
-  xnee_print_xnee_settings (xd, xd->err) ;
-  xnee_record_print_record_range (xd, xd->err) ;
-  fprintf (stderr, "Press enter to continue:\n");
-  getchar();
-  */
-  return XNEE_TRUE;
-}
-
-
 /**************************************************************
  *                                                            *
  * xnee_replay_main_loop                                      *
@@ -358,6 +225,7 @@ xnee_replay_main_loop(xnee_data *xd, int read_mode)
 	{
 	  ret_str = fgets(tmp, 256, xd->data_file);
 
+	  
 	  if ( ret_str == NULL)
           {
              ret = -1;
@@ -705,7 +573,9 @@ xnee_setup_rep_recording(xnee_data *xd)
   xnee_verbose((xd, "--- \t %d\n", (int)xrs->rContext));             
   xnee_verbose((xd, "--- \t %d\n", (int)xrs->rState));             
 
-  if( XRecordGetContext(xd->control, xrs->rContext, (XRecordState **) xrs->rState) == 0)
+  /*  if( XRecordGetContext(xd->control, 
+			xrs->rContext, 
+			(XRecordState **) xrs->rState) == 0)
     {
       xnee_print_error ("\n Couldn't get the context information for Display %d\n", (int) xd->control) ;
       exit(XNEE_BAD_CONTEXT);
@@ -713,7 +583,7 @@ xnee_setup_rep_recording(xnee_data *xd)
   
   xnee_verbose((xd, "\t  GetContext      0x%lx (%d clients intercepted))\n", 
 		xrs->rContext, (int) ( (xrs->rState) - (xrs->nclients) ) ));   
-  
+  */
   xnee_verbose((xd, "--- xnee_setup_rep_recording  freeing state \n"));             
 
   XRecordFreeState(xrs->rState); 
@@ -721,13 +591,13 @@ xnee_setup_rep_recording(xnee_data *xd)
   xnee_verbose((xd, "--- xnee_setup_rep_recording  setting rstate \n"));             
   xd->record_setup->rState=NULL; 
 
-  /*
+  
   xnee_verbose((xd, "XSync()\n"));
   XSync  (xd->control, False); 
   xnee_verbose((xd, "XFlush()\n"));
   XFlush (xd->control); 
   XSynchronize(xd->data, True);  
-  */
+  
 
   
   xnee_verbose((xd, "--- xnee_setup_rep_recording enabling async \n"));             
