@@ -77,12 +77,21 @@ xnee_get_max_range (xnee_data *xd)
 {
   int i=0;
   int max_val=0;
-  for ( i=0 ; i<XNEE_NR_OF_TYPES ; i++)
+
+  if (!xd->record_setup->active)
     {
-      max_val=XNEE_MAX (xd->xnee_info.data_ranges[i], max_val);
+      max_val = 0;
     }
-  xnee_verbose((xd, "Returning max_val=%d\n", max_val));
-  /* Returns the number of RecordRanges allocated so far */
+  else
+    {
+      for ( i=0 ; i<XNEE_NR_OF_TYPES ; i++)
+	{
+	  max_val=XNEE_MAX (xd->xnee_info.data_ranges[i], max_val);
+	}
+      xnee_verbose((xd, "Returning max_val=%d\n", max_val));
+      /* Returns the number of RecordRanges allocated so far */
+    }
+
   return max_val;
 }
 
@@ -166,6 +175,7 @@ xnee_close_down(xnee_data* xd)
   XNEE_DEBUG ( (stderr ," --> xnee_close_down() at 0.4 \n"  )); 
   if ( xd->data!=NULL)  
     {
+/*       printf ("close data in %s   ---> %d\n", __func__, xd->data); */
       xnee_verbose((xd, "Closing displays data=%d \n", (int) xd->data));
       XCloseDisplay ( xd->data );
     }
@@ -191,38 +201,22 @@ xnee_close_down(xnee_data* xd)
   xd->rc_file=NULL;
   xnee_verbose((xd ," --  xnee_close_down() free rc_file <-- %d\n", ret));
 
-  if (xd->err_file!=stdout)
-    {
-      xnee_verbose((xd ," --  xnee_close_down() free out_file \n"  ));
-      ret = xnee_free_file (xd, xd->out_name,  xd->out_file);
-      xd->out_file=NULL;
-      xnee_verbose((xd ," --  xnee_close_down() free out_file <-- %d\n", ret));
-    }
 
-  if (xd->rt_file!=stdout)
-    {
-      xnee_verbose((xd ," --  xnee_close_down() free rt_file \n"  ));
-      ret = xnee_free_file (xd, xd->rt_name,  xd->rt_file);
-      xd->rt_file=NULL;
-      xnee_verbose((xd ," --  xnee_close_down() free rt_file <-- %d\n", ret));
-    }
+  xnee_verbose((xd ," --  xnee_close_down() free rt_file \n"  ));
+  ret = xnee_free_file (xd, xd->rt_name,  xd->rt_file);
+  xd->rt_file=NULL;
+  xnee_verbose((xd ," --  xnee_close_down() free rt_file <-- %d\n", ret));
+  
+  xnee_verbose((xd ," --  xnee_close_down() free err_file\n"  ));
 
-  if (xd->err_file!=stderr)
-    {
-      xnee_verbose((xd ," --  xnee_close_down() free err_file\n"  ));
-      ret = xnee_free_file (xd, xd->err_name,  xd->err_file); 
-      xd->err_file=NULL;
-      xnee_verbose((xd ," --  xnee_close_down() free err_file <-- %d\n", ret));
-    }
+  ret = xnee_free_file (xd, xd->err_name,  xd->err_file); 
+  xd->err_file=NULL;
 
-  xnee_verbose((xd, "finished closing fds\n"));
+  ret = xnee_free_file (xd, xd->out_name,  xd->out_file);
+  xd->out_file=NULL;
 
-
-  XNEE_DEBUG ( (stderr ," --> xnee_close_down() at 0.6 \n"  ));
-  xnee_verbose((xd, "Freeeing data "));
   ret = xnee_free_xnee_data(xd);
   xd=NULL;
-
 }
 
 
@@ -237,6 +231,8 @@ int
 xnee_init(xnee_data* xd)
 {
   int ret ; 
+  int i ; 
+  char *tmp;
   
   if (xd == NULL) 
     {
@@ -274,8 +270,10 @@ xnee_init(xnee_data* xd)
   xd->data_file     = (FILE*) stdin  ;
   /*@access FILE@*/
   xd->out_file      = (FILE*) stdout ;
+  xd->saved_out_file= (FILE*) stdout ;
   /*@access FILE@*/
   xd->err_file      = (FILE*) stderr ;
+  xd->saved_err_file= (FILE*) stderr ;
   /*@access FILE@*/
   xd->rc_file       = NULL   ;
   /*@access FILE@*/
@@ -289,7 +287,15 @@ xnee_init(xnee_data* xd)
   xd->rc_name       = NULL  ;
   xd->rt_name       = NULL  ;
 
-  xd->display       = getenv ("DISPLAY");
+  tmp = getenv ((const char*)"DISPLAY");
+  if ( tmp != NULL )
+    {
+      xd->display = strdup(tmp);
+    }
+  else
+    {
+      xd->display = NULL;
+    }
   xd->distr_list    = NULL  ;
   xd->distr_list_size = 0   ;
   xd->cont          = True ;
@@ -309,9 +315,12 @@ xnee_init(xnee_data* xd)
       xnee_init_names();
   */
 
-  ret = xnee_grab_keys_init(xd);
-  XNEE_RETURN_IF_ERR(ret);
+  for (i=0;i<XNEE_NR_OF_TYPES;i++)
+    {
+      xd->xnee_info.data_ranges[i]=0;
+    }
 
+  xnee_new_grab_keys(xd);
 
   xd->in_use = 1;
 
@@ -506,7 +515,7 @@ xnee_rep_prepare(xnee_data *xd)
   ret = xnee_set_autorepeat (xd);
   XNEE_RETURN_IF_ERR (ret);
 
-  ret = xnee_init_ranges();
+  ret = xnee_refresh_ranges(xd);
   XNEE_RETURN_IF_ERR (ret);
 
   xnee_verbose((xd, "<-- xnee_rep_prepare returning %d\n", XNEE_OK));
